@@ -1,15 +1,17 @@
 #!/usr/bin/perl
 package SOAP::WSDL::XSD::Typelib::SimpleType;
 use strict;
-use Class::Std::Storable;
 use SOAP::WSDL::XSD::Typelib::Builtin;
 
+use version; our $VERSION = qv('2.00.02');
+
 package SOAP::WSDL::XSD::Typelib::SimpleType::restriction;
 use strict;
-use Class::Std::Storable;
 use SOAP::WSDL::XSD::Typelib::Builtin;
 use base qw(SOAP::WSDL::XSD::Typelib::SimpleType);
 
+use version; our $VERSION = qv('2.00.02');
+
 1;
 __END__
 
@@ -17,7 +19,7 @@ __END__
 
 =head1 NAME
 
-SOAP::WSDL::XSD::Typelib::SimpleType - simple type base class
+SOAP::WSDL::XSD::Typelib::SimpleType - simpleType base class
 
 =head1 DESCRIPTION
 
@@ -32,7 +34,7 @@ modelling XML Schema simpleType definitions.
     #    <restriction base="xsd:string" />
     # </simpleType>
     package MySimpleType;
-    use Class::Std::Storable;
+    use Class::Std::Fast::Storable constructor => 'none';
     # restriction base implemented via inheritance
     use SOAP::WSDL::XSD::Typelib::Builtin;
     use SOAP::WSDL::XSD::Typelib::SimpleType;
@@ -49,7 +51,7 @@ modelling XML Schema simpleType definitions.
     #    <list itemTipe="xsd:string" />
     # </simpleType>
     package MySimpleListType;
-    use Class::Std::Storable;
+    use Class::Std::Fast::Storable constructor => 'none';
     # restriction base implemented via inheritance
     use SOAP::WSDL::XSD::Typelib::Builtin;
     use base ('SOAP::WSDL::XSD::Typelib::SimpleType',
@@ -85,9 +87,9 @@ faint of heart).
 simpleType classes derived via restriction must inherit from these classes in
 exactly this order:
 
- SOAP::WSDL::XSD::Typelib::SimpleType               # you may leave out this
- SOAP::WSDL::XSD::Typelib::SimpleType::restriction  # derive by retriction
- The::Restriction::Base::Class                      # resytriction base
+ SOAP::WSDL::XSD::Typelib::SimpleType               # you may leave this out
+ SOAP::WSDL::XSD::Typelib::SimpleType::restriction  # derive by restriction
+ The::Restriction::Base::Class                      # restriction base
 
 The::Restriction::Base::Class can either be a builtin class (see
 SOAP::WSDL::XSD::Builtin) or another simpleType class.
@@ -96,13 +98,15 @@ The slight inconsistency between the these variants is caused by the
 restriction element, which has different meanings for simpleType and
 complexType definitions.
 
-=head1 Bugs and limitations
+=back
 
-=over *
+=head1 BUGS AND LIMITATIONS
+
+=over
 
 =item * Thread safety
 
-SOAP::WSDL::XSD::Typelib::SimpleType uses Class::Std::Storable which uses
+SOAP::WSDL::XSD::Typelib::SimpleType uses Class::Std::Fast::Storable which uses
 Class::Std. Class::Std is not thread safe, so
 SOAP::WSDL::XSD::Typelib::SimpleType is neither.
 
@@ -116,15 +120,23 @@ No facets are implemented yet.
 
 =back
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2004-2007 Martin Kutter.
+
+This file is part of SOAP-WSDL. You may distribute/modify it under the same
+terms as perl itself
+
 =head1 AUTHOR
 
-Replace whitespace by @ in e-mail address.
+Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
- Martin Kutter E<gt>martin.kutter fen-net.deE<lt>
+=head1 REPOSITORY INFORMATION
 
-=head1 COPYING
-
-This library is free software, you may distribute/modify it under the
-same terms as perl itself
+ $Rev: 672 $
+ $LastChangedBy: kutterma $
+ $Id: SimpleType.pm 672 2008-05-16 09:37:59Z kutterma $
+ $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/SimpleType.pm $
 
 =cut
+
